@@ -372,6 +372,7 @@ class EnrolledService(proto.Message):
             -  Cloud Key Management Service
             -  Compute Engine
             -  Cloud Dataflow
+            -  Cloud Dataproc
             -  Cloud DLP
             -  Cloud EKM
             -  Cloud HSM
@@ -385,6 +386,7 @@ class EnrolledService(proto.Message):
             -  Organization Policy Serivice
             -  Persistent Disk
             -  Resource Manager
+            -  Secret Manager
             -  Speaker ID
 
             Note: These values are supported as input for legacy
@@ -401,12 +403,14 @@ class EnrolledService(proto.Message):
             -  cloudsql.googleapis.com
             -  compute.googleapis.com
             -  dataflow.googleapis.com
+            -  dataproc.googleapis.com
             -  dlp.googleapis.com
             -  iam.googleapis.com
             -  logging.googleapis.com
             -  orgpolicy.googleapis.com
             -  pubsub.googleapis.com
             -  spanner.googleapis.com
+            -  secretmanager.googleapis.com
             -  speakerid.googleapis.com
             -  storage.googleapis.com
 
